==> gnustep-dl2_0.9.1.orig.tar.gz: gnustep-dl2-0.9.1.orig/Tools/NSDictionary+GSDoc.h <==
/* -*-objc-*-
   NSDictionary+GSDoc.h <title></title>

   Copyright (C) 2000-2002 Free Software Foundation, Inc.

   Author: Manuel Guesdon <mguesdon@orange-concept.com>
   Date: August 2000

   $Revision: 1.2 $
   $Date: 2004/04/17 11:30:47 $

   <abstract></abstract>

   This file is part of the GNUstep Database Library.

   <license>
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
   </license>
**/

// $Id: NSDictionary+GSDoc.h,v 1.2 2004/04/17 11:30:47 ayers Exp $

#ifndef __NSDictionary_GSDoc_h__
#define __NSDictionary_GSDoc_h__

#include <Foundation/NSDictionary.h>


@interface NSDictionary (GSDoc)

- (NSString *)gsdocContentWithIdPtr: (int *)xmlIdPtr;
- (NSString *)gsdocContentWithTagName: (NSString *)tagName
				idPtr: (int *)xmlIdPtr;

@end


#endif /* __NSDictionary_GSDoc_h__ */

==> gnustep-dl2_0.11.0.orig.tar.gz: gnustep-dl2-0.11.0/Tools/NSDictionary+GSDoc.h <==
/* -*-objc-*-
   NSDictionary+GSDoc.h <title></title>

   Copyright (C) 2000-2002,2004,2005 Free Software Foundation, Inc.

   Author: Manuel Guesdon <mguesdon@orange-concept.com>
   Date: August 2000

   $Revision: 21645 $
   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $

   <abstract></abstract>

   This file is part of the GNUstep Database Library.

   <license>
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
   </license>
**/

// $Id: NSDictionary+GSDoc.h 21645 2005-08-17 08:07:57Z ayers $

#ifndef __NSDictionary_GSDoc_h__
#define __NSDictionary_GSDoc_h__

#include <Foundation/NSDictionary.h>


@interface NSDictionary (GSDoc)

- (NSString *)gsdocContentWithIdPtr: (int *)xmlIdPtr;
- (NSString *)gsdocContentWithTagName: (NSString *)tagName
				idPtr: (int *)xmlIdPtr;

@end


#endif /* __NSDictionary_GSDoc_h__ */
